@@ -14,9 +14,9 @@ use Cwd;
 use File::Spec;
 use File::Temp;
 use List::Util qw(sum);
-use Data::Dump qw( pp );
+#use Data::Dump qw( pp );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -604,7 +604,7 @@ or through the web interface at L<http://rt.cpan.org>.
 James E. Keenan (jkeenan at cpan dot org).  When sending correspondence, please
 include 'Devel::Git::MultiBisect' or 'Devel-Git-MultiBisect' in your subject line.
 
-Creation date:  November 04 2016. Last modification date:  November 04 2016.
+Creation date:  November 09 2016. Last modification date:  November 09 2016.
 
 Development repository: L<https://github.com/jkeenan/devel-git-multibisect>
 
